@@ -1,6 +1,6 @@
 package My::YAML::Active::WritePerson;
 
-use 5.006001;
+use 5.006;
 use strict;
 use warnings;
 
@@ -10,12 +10,12 @@ our $VERSION = '0.01';
 
 sub yaml_activate {
     my ($self, $phase) = @_;
-    UNIVERSAL::isa($self, 'HASH') && exists $self->{person} or
-        die 'YAML::Active::Eval expects a hash ref like { person => {...} }';
+    UNIVERSAL::isa($self, 'HASH') && exists $self->{person} or die
+        'My::YAML::Active::WritePerson expects a hash ref like { person => {...} }';
     $main::result .= "Writing person:\n";
     my $person = node_activate($self->{person}, $phase);
     $main::result .= " $_ => $person->{$_}\n" for sort keys %$person;
-    return 1;   # rc: OK
+    return $person->{personname};   # rc: OK
 }
 
 
